from pathlib import Path

# Deprecated: legacy state locations kept for compatibility with old versions.
TEMPLATES_DIR = Path(__file__).parent / "templates"
RUNTIME_DIR = Path(__file__).parent / "runtime"

