server {
  listen 443 ssl http2; listen [::]:443 ssl http2;
  server_name {{ domain }};
  ssl_certificate /etc/letsencrypt/live/{{ domain }}/fullchain.pem;
  ssl_certificate_key /etc/letsencrypt/live/{{ domain }}/privkey.pem;
  add_header Strict-Transport-Security $hsts_header always;

  location /health { access_log off; return 200 "healthy\n"; }

  location /ws/ {
    proxy_read_timeout 86400; proxy_send_timeout 86400; proxy_connect_timeout 75s; proxy_buffering off;
    proxy_pass http://{{ upstream }}; proxy_http_version 1.1; proxy_set_header Upgrade $http_upgrade; proxy_set_header Connection "upgrade";
    proxy_set_header Host $host; proxy_set_header X-Real-IP $remote_addr; proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for; proxy_set_header X-Forwarded-Proto $scheme;
  }

  location / {
    proxy_pass http://{{ upstream }}; proxy_set_header Host $host; proxy_set_header X-Real-IP $remote_addr; proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for; proxy_set_header X-Forwarded-Proto $scheme; proxy_http_version 1.1; proxy_set_header Connection "upgrade"; proxy_buffering off; proxy_request_buffering off;
  }
}
